Polls
=====

.. autoclass:: asyncpraw.models.reddit.poll.PollData
    :inherited-members:

.. autoclass:: asyncpraw.models.reddit.poll.PollOption
    :inherited-members:

.. include:: ../models/note_dynamically_provided_attributes.txt
